"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PAPAGO = void 0;
const api_request_1 = require("../../utils/api_request");
const processing_types_1 = require("../../types/processing_types");
const errors_1 = require("../../utils/errors");
class PAPAGO {
    /**
     * Creates an instance of PAPAGO service agent.
     *
     * @param {string} baseURL The baseURL of each session ( based on service )
     * @param {NaverOpenApiAuthType} apiAuth Service identification for using NaverOpenApi
     * @memberof PAPAGO
     */
    constructor(baseUrl, openApiAuth) {
        this.client = new api_request_1.ApiClient(baseUrl);
        this.openApiAuth = openApiAuth;
    }
    /**
     * Construct Translation Service apiRequest. pass source, target language and text want to translate.
     * Input parameter validation is implemented which handles API service Error beforehand request.
     * @async
     * @access public
     * @param {string} source - text's language which want to translate.
     * @param {string} target - language which want to be translated.
     * @param {string} text - text which want to be translated.
     * @returns {Promise<ApiClientResponse<PapagoTranslationReturnType>>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof PAPAGO
     */
    async translation(source, target, text) {
        const path = 'nmt/v1/translation';
        const method = 'POST';
        // construct signature and headers
        const headers = {
            'Content-Type': 'application/json; charset=utf-8',
            'X-NCP-APIGW-API-KEY-ID': this.openApiAuth.clientId,
            'X-NCP-APIGW-API-KEY': this.openApiAuth.clientSecret
        };
        const body = {
            source: source,
            target: target,
            text: text
        };
        const apiRequest = {
            path: path,
            method: method,
            headers: headers,
            body: body
        };
        let serviceError = this.languageSupportValidation(source, target, text);
        return this.client.request(apiRequest, serviceError);
    }
    /**
     * Construct Detect Language Service apiRequest. pass text want to detect language.
     * Input parameter validation is implemented which handles API service Error beforehand request.
     * @async
     * @access public
     * @param {string} text - text which want to detect language.
     * @returns {Promise<ApiClientResponse<PapagoDetectLanguageReturnType>>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof PAPAGO
     */
    async detectLanguage(text) {
        const path = 'langs/v1/dect';
        const method = 'POST';
        // construct signature and headers
        const headers = {
            'Content-Type': 'application/json; charset=utf-8',
            'X-NCP-APIGW-API-KEY-ID': this.openApiAuth.clientId,
            'X-NCP-APIGW-API-KEY': this.openApiAuth.clientSecret
        };
        const body = {
            query: text
        };
        const apiRequest = {
            path: path,
            method: method,
            headers: headers,
            body: body
        };
        let serviceError = this.detectLanguageValidation(text);
        return this.client.request(apiRequest, serviceError);
    }
    /**
     * Construct Korean Name Romanizer Service apiRequest. pass korean name to be romanized analyzation.
     * Input parameter validation is implemented which handles API service Error beforehand request.
     * @async
     * @access public
     * @param {string} koreanName - koreanName which is to be romanized.
     * @returns {Promise<ApiClientResponse<PapagoKoreanNameRomanizerReturnType>>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof PAPAGO
     */
    async koreanNameRominizer(koreanName) {
        const path = `krdict/v1/romanization?query=${encodeURI(koreanName)}`;
        const method = 'GET';
        // construct signature and headers
        const headers = {
            'Content-Type': 'application/json; charset=utf-8',
            'X-NCP-APIGW-API-KEY-ID': this.openApiAuth.clientId,
            'X-NCP-APIGW-API-KEY': this.openApiAuth.clientSecret
        };
        const apiRequest = {
            path: path,
            method: method,
            headers: headers
        };
        let serviceError = this.koreanNameRomanizerValidation(koreanName);
        return this.client.request(apiRequest, serviceError);
    }
    /**
     * Parameter validation for translation Service.
     * It provides source / target validations with languagesupports, and text validation for length allowable by service.
     * @access private
     * @param {string} source - text's language which want to translate.
     * @param {string} target - language which want to be translated.
     * @param {string} text - text which want to be translated.
     * @returns {ServiceError | undefined} return ServiceError of each error if parameter violate API rules.
     * @memberof PAPAGO
     */
    languageSupportValidation(source, target, text) {
        // get all Support Languages for translation api 
        const languageSupports = Object.values(processing_types_1.PAPAGOlanguages);
        if (source.length === 0)
            return new errors_1.ServiceError("Source parameter is needed, please check it");
        else if (!(languageSupports.includes(source)))
            return new errors_1.ServiceError("Unsupported source language, please check it");
        else if (target.length === 0)
            return new errors_1.ServiceError("Target parameter is needed, please check it");
        else if (!(languageSupports.includes(target)))
            return new errors_1.ServiceError("Unsupported target language, please check it");
        else if (source === target)
            return new errors_1.ServiceError("Source and target are identical, please check it");
        else if (!(Object.entries(processing_types_1.PAPAGOlanguageSupports).filter(function (s) { return s[0] === source; }).map(function (s) { return s[1]; })[0].includes(target)))
            return new errors_1.ServiceError("There is no source–to-target translator, please check it");
        else if (text.length === 0)
            return new errors_1.ServiceError("Text parameter is needed, please check it");
        else if (text.length > 5000)
            return new errors_1.ServiceError("Text parameter exceeds the maximum length, please check it");
        return undefined;
    }
    /**
     * Parameter validation for translation Service.
     * It provides text validation for length allowable by service.
     * @access private
     * @param {string} text - text which want to detect language.
     * @returns {ServiceError | undefined} return ServiceError of each error if parameter violate API rules.
     * @memberof PAPAGO
     */
    detectLanguageValidation(text) {
        // for detectLanguage, text parameter is needed
        if (text.length === 0)
            return new errors_1.ServiceError("Text parameter is needed, please check it");
        return undefined;
    }
    /**
     * Parameter validation for translation Service.
     * It provides name string validation for length, rules allowable by service by regex.
     * @access private
     * @param {string} name - koreanName which is to be romanized.
     * @returns {ServiceError | undefined} return ServiceError of each error if parameter violate API rules.
     * @memberof PAPAGO
     */
    koreanNameRomanizerValidation(name) {
        // for koreanNameRomanazier, name parameter is needed and is to be only korean
        if (name.length === 0)
            return new errors_1.ServiceError("KoreanName parameter is needed, please check it");
        else if (!((/^[가-힣]+$/).test(name)))
            return new errors_1.ServiceError("Only full Korean name parameter with no white space is allowed, please check it");
        return undefined;
    }
}
exports.PAPAGO = PAPAGO;
