"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiClient = void 0;
const axios_1 = __importDefault(require("axios"));
const errors_1 = require("./errors");
class ApiClient {
    /**
     * Creates an instance of ApiClient.
     *
     * @param {string} baseURL The baseURL of each session ( based on service )
     * @param {(number | undefined)} timeout Timeout configuration ( millisecond )
     * @memberof ApiClient
     */
    constructor(baseURL, timeout = 2000) {
        this.client = axios_1.default.create({
            baseURL: baseURL,
            timeout: timeout,
        });
    }
    /**
     * Executing request and wrapping it with ApiClientResponse
     *  will return ApiClientResponse if success, with data else with error message
     *
     * @template T - Data type matched with each API's response
     * @async
     * @access public
     * @param {ApiRequest} apiRequest - ApiRequest configs for request
     * @returns {Promise<ApiClientResponse<T>>} return Promise response of wrapped with error handling
     * @memberof ApiClient
     */
    async request(apiRequest, serviceError) {
        try {
            if (serviceError)
                throw serviceError;
            const val = await this.createRequest(apiRequest);
            return {
                isSuccess: true,
                data: val
            };
        }
        catch (error) {
            return {
                isSuccess: false,
                errorMessage: error.message
            };
        }
    }
    /**
     * Execute request and return Promise with error or response if success
     *  Wrapping axios-request with Promise's resolve / reject for error handling
     *
     * @template T - Data type matched with each API's response
     * @access private
     * @param {ApiRequest} apiRequest - ApiRequest configs for request
     * @returns {Promise<T>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof ApiClient
     */
    createRequest(apiRequest) {
        return new Promise((resolve, reject) => {
            this.urlRequest(apiRequest)
                .then((response) => {
                resolve(response.data);
            })
                .catch((error) => {
                if (error.response) {
                    reject(new errors_1.ApiError(errors_1.ApiErrorEnum["httpStatusCode"], error.response.status));
                }
                else if (error.request) {
                    reject(new errors_1.ApiError(errors_1.ApiErrorEnum["noResponseFromServer"]));
                }
                else {
                    reject(new errors_1.ApiError(errors_1.ApiErrorEnum["requestConfigurationError"]));
                }
            });
        });
    }
    /**
     * Return configured AxiosInstance's request execution
     *  Before launch axios-request, launch url validation if invalid, throw Error else return AxiosResponses
     *
     * @access private
     * @param {ApiRequest} apiRequest - ApiRequest configs for request
     * @returns {Promise<AxiosResponse>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof ApiClient
     */
    urlRequest(apiRequest) {
        const { path, method, headers, body } = apiRequest;
        // url validation
        if (!this.validateURL(this.client.defaults.baseURL + apiRequest.path))
            throw new errors_1.ApiError(errors_1.ApiErrorEnum["invalidURL"]);
        return this.client.request({
            url: path,
            method: method,
            headers: headers,
            data: body
        });
    }
    /**
     * URL validation using regex
     * @access private
     * @param url
     * @returns {boolean}
     * @memberof ApiClient
     */
    validateURL(url) {
        var res = url.match(/(http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?/);
        return (res !== null);
    }
}
exports.ApiClient = ApiClient;
